@@ -23,30 +23,17 @@
 
 #include "AbstractViewContainer.h"
 
-class AbstractViewBase;
-class ApplicationBackend;
-class Category;
+class AbstractResourcesBackend;
 class CategoryViewWidget;
 
-namespace QApt {
-    class Backend;
-}
-
 class AvailableView : public AbstractViewContainer
 {
     Q_OBJECT
 public:
-    AvailableView(QWidget *parent, ApplicationBackend *m_appBackend);
-    ~AvailableView();
+    AvailableView(QWidget *parent);
 
 private:
-    QApt::Backend *m_backend;
-    ApplicationBackend *m_appBackend;
-
     CategoryViewWidget *m_categoryViewWidget;
-
-public Q_SLOTS:
-    void setBackend(QApt::Backend *backend);
 };
 
 #endif
