@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
+ *   Copyright © 2010-2012 Jonathan Thomas <echidnaman@kubuntu.org>        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
  *   modify it under the terms of the GNU General Public License as        *
@@ -29,23 +29,17 @@
 #include <KIcon>
 #include <KLocale>
 
-// LibQApt includes
-#include <LibQApt/Backend>
-
 // Libmuon includes
-#include <ApplicationBackend.h>
 #include <Category/Category.h>
 #include <Category/CategoryModel.h>
 
 // Own includes
-#include "../ApplicationView/ApplicationViewWidget.h"
-#include "../BreadcrumbWidget/BreadcrumbItem.h"
+#include "ResourceView/ResourceViewWidget.h"
+#include "BreadcrumbWidget/BreadcrumbItem.h"
 #include "CategoryView.h"
 
-CategoryViewWidget::CategoryViewWidget(QWidget *parent, ApplicationBackend *appBackend)
+CategoryViewWidget::CategoryViewWidget(QWidget *parent)
     : AbstractViewBase(parent)
-    , m_backend(0)
-    , m_appBackend(appBackend)
     , m_searchView(0)
 {
     m_searchable = true;
@@ -59,15 +53,6 @@ CategoryViewWidget::CategoryViewWidget(QWidget *parent, ApplicationBackend *appB
            this, SLOT(onIndexActivated(QModelIndex)));
 }
 
-CategoryViewWidget::~CategoryViewWidget()
-{
-}
-
-void CategoryViewWidget::setBackend(QApt::Backend *backend)
-{
-    m_backend = backend;
-}
-
 void CategoryViewWidget::setCategories(const QList<Category *> &categoryList,
                                        const QString &rootName,
                                        const QIcon &icon)
@@ -99,10 +84,9 @@ void CategoryViewWidget::onIndexActivated(const QModelIndex &index)
 
     switch (index.data(CategoryModel::CategoryTypeRole).toInt()) {
     case CategoryModel::CategoryType: { // Displays the apps in a category
-        m_subView = new ApplicationViewWidget(this, m_appBackend);
+        m_subView = new ResourceViewWidget(this);
 
-        ApplicationViewWidget *appView = static_cast<ApplicationViewWidget *>(m_subView);
-        appView->setBackend(m_backend);
+        ResourceViewWidget *appView = static_cast<ResourceViewWidget *>(m_subView);
         appView->setFiltersFromCategory(category);
         appView->setTitle(category->name());
         appView->setIcon(KIcon(category->icon()));
@@ -110,10 +94,9 @@ void CategoryViewWidget::onIndexActivated(const QModelIndex &index)
     }
         break;
     case CategoryModel::SubCatType: { // Displays the subcategories of a category
-        m_subView = new CategoryViewWidget(this, m_appBackend);
+        m_subView = new CategoryViewWidget(this);
 
         CategoryViewWidget *subCatView = static_cast<CategoryViewWidget *>(m_subView);
-        subCatView->setBackend(m_backend);
         subCatView->setCategories(category->subCategories(), category->name(),
                                   KIcon(category->icon()));
     }
@@ -139,8 +122,7 @@ void CategoryViewWidget::search(const QString &text)
     }
 
     if (!m_searchView) {
-        m_searchView = new ApplicationViewWidget(this, m_appBackend);
-        m_searchView->setBackend(m_backend);
+        m_searchView = new ResourceViewWidget(this);
         m_searchView->setTitle(i18nc("@label", "Search Results"));
         m_searchView->setIcon(KIcon("applications-other"));
 
@@ -170,5 +152,3 @@ void CategoryViewWidget::onSearchViewDestroyed()
 {
     m_searchView = 0;
 }
-
-#include "CategoryViewWidget.moc"
