@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
+ *   Copyright © 2010-2012 Jonathan Thomas <echidnaman@kubuntu.org>        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
  *   modify it under the terms of the GNU General Public License as        *
@@ -31,39 +31,29 @@ class QIcon;
 class QStandardItemModel;
 class QString;
 
-class ApplicationBackend;
-class ApplicationViewWidget;
 class Category;
 class CategoryView;
 
-namespace QApt {
-    class Backend;
-}
+class ResourceViewWidget;
 
 class CategoryViewWidget : public AbstractViewBase
 {
     Q_OBJECT
 public:
-    CategoryViewWidget(QWidget *parent, ApplicationBackend *appBackend);
-    ~CategoryViewWidget();
+    CategoryViewWidget(QWidget *parent);
 
     void setCategories(const QList<Category *> &categoryList,
                        const QString &rootText,
                        const QIcon &rootIcon);
-    virtual void search(const QString &text);
+    void search(const QString &text);
 
-private:
-    QApt::Backend *m_backend;
-    ApplicationBackend *m_appBackend;
+private:\
     CategoryModel *m_categoryModel;
     QHash<QModelIndex, AbstractViewBase *> m_subViewHash;
 
     CategoryView *m_categoryView;
     AbstractViewBase *m_subView;
-    ApplicationViewWidget *m_searchView;
-
-public Q_SLOTS:
-    void setBackend(QApt::Backend *backend);
+    ResourceViewWidget *m_searchView;
 
 private Q_SLOTS:
     void onIndexActivated(const QModelIndex &index);
