@@ -34,12 +34,14 @@
 #include <KProcess>
 #include <KProtocolManager>
 #include <KStandardDirs>
+#include <KIO/Job>
 #include <KDebug>
 
 // LibQApt/DebconfKDE includes
 #include <LibQApt/Backend>
 #include <LibQApt/Transaction>
 #include <DebconfGui.h>
+#include <qjson/parser.h>
 
 // Own includes
 #include "MuonStrings.h"
@@ -50,10 +52,11 @@
 #include "ApplicationUpdates.h"
 #include "QAptActions.h"
 #include "MuonMainWindow.h"
+#include <MuonDataSources.h>
 
 ApplicationBackend::ApplicationBackend(QObject *parent)
     : AbstractResourcesBackend(parent)
-    , m_backend(nullptr)
+    , m_backend(new QApt::Backend(this))
     , m_reviewsBackend(new ReviewsBackend(this))
     , m_isReloading(false)
     , m_currentTransaction(nullptr)
@@ -65,6 +68,9 @@ ApplicationBackend::ApplicationBackend(QObject *parent)
     connect(this, SIGNAL(reloadFinished()), SIGNAL(updatesCountChanged()));
     connect(this, SIGNAL(backendReady()), SIGNAL(updatesCountChanged()));
     connect(m_reviewsBackend, SIGNAL(ratingsReady()), SIGNAL(allDataChanged()));
+    connect(m_backendUpdater, SIGNAL(updatesFinnished()), SLOT(reload()));
+    
+    QTimer::singleShot(10, this, SLOT(initBackend()));
 }
 
 ApplicationBackend::~ApplicationBackend()
@@ -101,19 +107,22 @@ QVector<Application *> init(QApt::Backend *backend, QThread* thread)
         tempList << app;
     }
 
+    // To be added an Application must have a package that:
+    // a) exists
+    // b) is not on the blacklist
+    // c) if not downloadable, then it must already be installed
     for (Application *app : tempList) {
         bool added = false;
         QApt::Package *pkg = app->package();
         if (app->isValid()) {
             if ((pkg) && !pkgBlacklist.contains(pkg->name())) {
                 appList << app;
+                app->moveToThread(thread);
                 added = true;
             }
         }
 
-        if(added)
-            app->moveToThread(thread);
-        else
+        if(!added)
             delete app;
     }
 
@@ -140,10 +149,9 @@ void ApplicationBackend::setApplications()
     m_appList = m_watcher->future().result();
 
     // Populate origin lists
-    QApt::Package *pkg;
     for (Application *app : m_appList) {
         app->setParent(this);
-        pkg = app->package();
+        QApt::Package* pkg = app->package();
         if (pkg->isInstalled())
             m_instOriginList << pkg->origin();
         else
@@ -154,6 +162,9 @@ void ApplicationBackend::setApplications()
     m_instOriginList.remove(QString());
     m_originList += m_instOriginList;
     emit backendReady();
+    
+    KIO::StoredTransferJob* job = KIO::storedGet(KUrl(MuonDataSources::screenshotsSource(), "/json/packages"),KIO::NoReload, KIO::DefaultFlags|KIO::HideProgressInfo);
+    connect(job, SIGNAL(finished(KJob*)), SLOT(initAvailablePackages(KJob*)));
 
     if (m_aptify)
         m_aptify->setCanExit(true);
@@ -284,11 +295,12 @@ void ApplicationBackend::updateProgress(int percentage)
 
 bool ApplicationBackend::confirmRemoval(QApt::StateChanges changes)
 {
-    if (changes[QApt::Package::ToRemove].isEmpty()) {
+    const QApt::PackageList removeList = changes.value(QApt::Package::ToRemove);
+    if (removeList.isEmpty())
         return true;
-    }
-    QHash<QApt::Package::State, QApt::PackageList> removals;
-    removals[QApt::Package::ToRemove] = changes[QApt::Package::ToRemove];
+
+    QApt::StateChanges removals;
+    removals[QApt::Package::ToRemove] = removeList;
 
     ChangesDialog *dialog = new ChangesDialog(0, removals);
 
@@ -564,23 +576,15 @@ QPair<TransactionStateTransition, Transaction*> ApplicationBackend::currentTrans
     return ret;
 }
 
-bool ApplicationBackend::providesResouce(AbstractResource* res) const
-{
-    return qobject_cast<Application*>(res);
-}
-
 AbstractBackendUpdater* ApplicationBackend::backendUpdater() const
 {
     return m_backendUpdater;
 }
 
-void ApplicationBackend::integrateMainWindow(MuonMainWindow* w)
+void ApplicationBackend::integrateMainWindow(QAptActions* w)
 {
-    m_backend = new QApt::Backend(this);
-    m_aptify = new QAptActions(w, m_backend);
-    QTimer::singleShot(10, this, SLOT(initBackend()));
-
-    m_aptify->setupActions();
+    m_aptify = w;
+    m_aptify->setBackend(m_backend);
     connect(m_aptify, SIGNAL(sourcesEditorFinished()), SLOT(reload()));
 }
 
@@ -637,3 +641,27 @@ void ApplicationBackend::sourcesEditorClosed()
     reload();
     emit sourcesEditorFinished();
 }
+
+void ApplicationBackend::initAvailablePackages(KJob* j)
+{
+    KIO::StoredTransferJob* job = qobject_cast<KIO::StoredTransferJob*>(j);
+    Q_ASSERT(job);
+    
+    bool ok=false;
+    QJson::Parser p;
+    QVariantList data = p.parse(job->data(), &ok).toMap().value("packages").toList();
+    if(!ok)
+        kWarning() << "errors!" << p.errorString();
+    else {
+        Q_ASSERT(!m_appList.isEmpty());
+        QSet<QString> packages;
+        foreach(const QVariant& v, data) {
+            packages += v.toMap().value("name").toString();
+        }
+        Q_ASSERT(packages.count()==data.count());
+        for(Application* a : m_appList) {
+            a->setHasScreenshot(packages.contains(a->packageName()));
+        }
+        qDebug(".");
+    }
+}
