@@ -89,16 +89,17 @@ ChangelogWidget::ChangelogWidget(QWidget *parent)
 
     int finalHeight = sizeHint().height();
 
-    QPropertyAnimation *anim1 = new QPropertyAnimation(this, "maximumSize", this);
+    QPropertyAnimation *anim1 = new QPropertyAnimation(this, "maximumHeight", this);
     anim1->setDuration(500);
     anim1->setEasingCurve(QEasingCurve::OutQuart);
-    anim1->setStartValue(QSize(QWIDGETSIZE_MAX, 0));
-    anim1->setEndValue(QSize(QWIDGETSIZE_MAX, finalHeight));
-    QPropertyAnimation *anim2 = new QPropertyAnimation(this, "minimumSize", this);
+    anim1->setStartValue(0);
+    anim1->setEndValue(finalHeight);
+
+    QPropertyAnimation *anim2 = new QPropertyAnimation(this, "minimumHeight", this);
     anim2->setDuration(500);
     anim2->setEasingCurve(QEasingCurve::OutQuart);
-    anim2->setStartValue(QSize(QWIDGETSIZE_MAX, 0));
-    anim2->setEndValue(QSize(QWIDGETSIZE_MAX, finalHeight));
+    anim2->setStartValue(0);
+    anim2->setEndValue(finalHeight);
 
     m_expandWidget = new QParallelAnimationGroup(this);
     m_expandWidget->addAnimation(anim1);
@@ -141,12 +142,12 @@ void ChangelogWidget::animatedHide()
 
 void ChangelogWidget::stopPendingJobs()
 {
+    // Delete any KJobs lying around. We could get stale package pointers if the jobs
+    // finish during a cache reload
     auto iter = m_jobHash.constBegin();
     while (iter != m_jobHash.constEnd()) {
-        KJob *getJob = iter.key();
-        disconnect(getJob, SIGNAL(result(KJob*)),
-                   this, SLOT(changelogFetched(KJob*)));
-        iter++;
+        iter.key()->deleteLater();
+        ++iter;
     }
 
     m_jobHash.clear();
@@ -155,6 +156,7 @@ void ChangelogWidget::stopPendingJobs()
 void ChangelogWidget::changelogFetched(KJob *job)
 {
     if (!m_package) {
+        job->deleteLater();
         m_jobHash.remove(job);
         return;
     }
@@ -188,6 +190,7 @@ void ChangelogWidget::changelogFetched(KJob *job)
     }
 
     changelogFile.remove();
+    job->deleteLater();
 }
 
 void ChangelogWidget::fetchChangelog()
@@ -207,7 +210,7 @@ void ChangelogWidget::fetchChangelog()
     KIO::FileCopyJob *getJob = KIO::file_copy(m_package->changelogUrl(),
                                filename, -1,
                                KIO::Overwrite | KIO::HideProgressInfo);
-
+    getJob->setAutoDelete(false);
     m_jobHash[getJob] = filename;
     connect(getJob, SIGNAL(result(KJob*)),
             this, SLOT(changelogFetched(KJob*)));
