@@ -101,7 +101,7 @@ void MainWindow::initGUI()
     mainLayout->addWidget(m_changelogWidget);
 
     m_backend = new QApt::Backend(this);
-    m_actions = new QAptActions(this, m_backend);
+    m_actions->setBackend(m_backend);
     connect(m_actions, SIGNAL(checkForUpdates()),
             this, SLOT(checkForUpdates()));
 
@@ -123,7 +123,7 @@ void MainWindow::initObject()
     }
 
     emit backendReady(m_backend);
-    m_canExit = true;
+    setCanExit(true);
 
     setActionsEnabled(); //Get initial enabled/disabled state
 }
@@ -144,7 +144,6 @@ void MainWindow::initError()
 void MainWindow::setupActions()
 {
     MuonMainWindow::setupActions();
-    m_actions->setupActions();
 
     m_loadSelectionsAction = actionCollection()->addAction("open_markings");
     m_loadSelectionsAction->setIcon(KIcon("document-open"));
@@ -237,7 +236,7 @@ void MainWindow::errorOccurred(QApt::ErrorCode error)
 
 void MainWindow::reload()
 {
-    m_canExit = false;
+    setCanExit(false);
     m_changelogWidget->stopPendingJobs();
 
     disconnect(m_updaterWidget, SIGNAL(packageChanged(QApt::Package*)),
@@ -253,7 +252,7 @@ void MainWindow::reload()
 
     checkPlugState();
 
-    m_canExit = true;
+    setCanExit(true);
 }
 
 void MainWindow::setActionsEnabled(bool enabled)
