@@ -21,6 +21,9 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+// LibQApt includes
+#include <LibQApt/Globals>
+
 // Own includes
 #include "../libmuon/MuonMainWindow.h"
 
@@ -29,6 +32,11 @@ class KDialog;
 class KMessageWidget;
 class KProcess;
 
+namespace QApt {
+    class Backend;
+    class Transaction;
+}
+
 class ChangelogWidget;
 class ProgressWidget;
 class UpdaterSettingsDialog;
@@ -41,6 +49,10 @@ public:
     MainWindow();
 
 private:
+    QApt::Backend *m_backend;
+    QApt::Transaction *m_trans;
+    QString m_pipe;
+
     ProgressWidget *m_progressWidget;
     UpdaterWidget *m_updaterWidget;
     ChangelogWidget *m_changelogWidget;
@@ -49,6 +61,8 @@ private:
     KMessageWidget *m_powerMessage;
     KMessageWidget *m_distUpgradeMessage;
 
+    KAction *m_loadSelectionsAction;
+    KAction *m_saveSelectionsAction;
     KAction *m_applyAction;
     KAction *m_createDownloadListAction;
     KAction *m_downloadListAction;
@@ -60,13 +74,15 @@ private:
 private Q_SLOTS:
     void initGUI();
     void initObject();
+    void initError();
     void setupActions();
-    void workerEvent(QApt::WorkerEvent event);
-    void errorOccurred(QApt::ErrorCode error, const QVariantMap &args);
+    void transactionStatusChanged(QApt::TransactionStatus status);
+    void errorOccurred(QApt::ErrorCode error);
     void reload();
     void setActionsEnabled(bool enabled = true);
     void checkForUpdates();
     void startCommit();
+    void setupTransaction(QApt::Transaction *trans);
     void editSettings();
     void closeSettingsDialog();
     void showHistoryDialog();
@@ -76,6 +92,9 @@ private Q_SLOTS:
     void checkDistUpgrade();
     void checkerFinished(int res);
     void launchDistUpgrade();
+
+Q_SIGNALS:
+    void backendReady(QApt::Backend *backend);
 };
 
 #endif // MAINWINDOW_H
